==> kubernetes-model-metrics-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/NodeMetricsListBuilder.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NodeMetricsListBuilder extends io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluentImpl<io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList,io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListBuilder>{
  public NodeMetricsListBuilder() {
    this(false);
  }
  public NodeMetricsListBuilder(java.lang.Boolean validationEnabled) {
    this(new NodeMetricsList(), validationEnabled);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent) {
    this(fluent, false);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NodeMetricsList(), validationEnabled);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance) {
    this(fluent, instance, false);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance) {
    this(instance,false);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList build() {
    NodeMetricsList buildable = new NodeMetricsList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeMetricsListBuilder that = (NodeMetricsListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-metrics-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/NodeMetricsListBuilder.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NodeMetricsListBuilder extends io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluentImpl<io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList,io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListBuilder>{
  public NodeMetricsListBuilder() {
    this(false);
  }
  public NodeMetricsListBuilder(java.lang.Boolean validationEnabled) {
    this(new NodeMetricsList(), validationEnabled);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent) {
    this(fluent, false);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NodeMetricsList(), validationEnabled);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance) {
    this(fluent, instance, false);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance) {
    this(instance,false);
  }
  public NodeMetricsListBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList build() {
    NodeMetricsList buildable = new NodeMetricsList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeMetricsListBuilder that = (NodeMetricsListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
